@@ -577,7 +577,7 @@ class RealServer(HttpClient, KempBaseObjectModel):
 
     def save(self, update=False):
         if not update:
-            response = self._get("/addrs", self._get_base_parameters())
+            response = self._get("/addrs", self.to_api_dict())
         else:
             response = self._get("/modrs", self.to_api_dict())
         if is_successful(response):
